#[non_exhaustive]pub enum GltfScalePreflightError {
Load(LoadError),
Unsupported {
manifest: Box<GltfCapabilityManifest>,
violations: Vec<GltfCapabilityViolation>,
count: usize,
},
}Expand description
Failure to load or safely preflight a captured scale source.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Load(LoadError)
The source was malformed or unreadable.
Unsupported
The source was parseable but contains unsupported raw domains.
Fields

manifest: Box<GltfCapabilityManifest>Complete inventory gathered before rejection.

violations: Vec<GltfCapabilityViolation>Deterministically ordered typed violations.