#[non_exhaustive]pub enum LoadError {
Io {
path: String,
source: Error,
},
Gltf(Error),
Buffer(String),
Malformed(String),
Topology(String),
}Expand description
Errors returned while loading .gltf or .glb input.
These are structural or operator errors. Semantic animation defects,
such as non-unit quaternions or seam pops, load successfully and are
reported by animsmith-core checks.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Io
The source file or one of its external buffers could not be read.
Gltf(Error)
The gltf parser rejected the container.
Buffer(String)
Buffer resolution or GLB framing failed.
Malformed(String)
Animation data is structurally malformed.
Topology(String)
The node graph is not a forest that can become a skeleton.